package com.iconplus.smartproc.repository;

import com.iconplus.smartproc.model.entity.DrpApproval;
import com.iconplus.smartproc.model.projection.DrpApprovalView;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Optional;

@Repository
public interface DrpApprovalRepository extends JpaRepository<DrpApproval, Long> {

    Optional<DrpApproval> findByDrpIdAndApproverUserIdAndIsDeleteFalse(Long drpId, Long userId);


    @Query(value = "SELECT da " +
            "FROM DrpApproval da " +
            "WHERE da.isDelete = false " +
            "AND da.drpId = :drpId " +
            "AND UPPER(da.level) = 'KOMITE' " +
            "AND da.isApprove = null")
    List<DrpApproval> getListKomiteApproval(Long drpId);


    List<DrpApproval> findByDrpIdAndIsDeleteFalse(Long drpId);

    @Query(value = "SELECT da.drpId as drpId, " +
            "da.approverUserId as approverUserId, " +
            "u.nama as nama, " +
            "j.jabatan as jabatan " +
            "FROM DrpApproval da " +
            "JOIN Users u ON u.id = da.approverUserId " +
            "JOIN Jabatan j ON j.id = u.jabatanId " +
            "WHERE da.isDelete = false " +
            "AND da.drpId = :drpId " +
            "AND da.isApprove = true " +
            "ORDER BY da.level desc")
    List<DrpApprovalView> getDrpApproval(Long drpId);

    Optional<DrpApproval> findByDrpIdAndLevelAndIsDeleteFalse(Long drpId, String level);

    @Query(value = "UPDATE drp_approval  " +
            "SET is_delete = 1 " +
            "WHERE drp_id = :drpId " +
            "AND is_delete = 0", nativeQuery = true)
    void deleteApprovalByDrpId(Long drpId);



}
