package com.iconplus.smartproc.repository;

import com.iconplus.smartproc.model.entity.Drp;
import com.iconplus.smartproc.model.projection.DrpApprovalView;
import com.iconplus.smartproc.model.projection.DrpView;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.sql.Timestamp;
import java.util.List;
import java.util.Optional;

@Repository
public interface DrpRepository extends JpaRepository<Drp, Long> {

    Optional<Drp> findByIdAndIsDeleteFalse(Long id);

    Optional<Drp> findByTahunAndIsDeleteFalse(Integer tahun);

    @Query(value = "SELECT d.id as id, " +
            "d.tahun as tahun, " +
            "d.approveStatus as approveStatus, " +
            "d.approveDate as approveDate, " +
            "d.isActive as isActive, " +
            "d.isDelete as isDelete, " +
            "count(dp.drpId) as totalPengadaan " +
            "FROM Drp d " +
            "LEFT JOIN DrpPengadaan dp ON dp.drpId = d.id " +
            "WHERE d.isDelete = false " +
            "GROUP BY d.id " +
            "ORDER BY d.id")
    Page<DrpView> findByIsDeleteFalse(Timestamp approveDate,
                                      Pageable pageable);

    Page<DrpView> findByIsDeleteFalse(Pageable pageable);

    @Query(value = "SELECT d.id as id, " +
            "d.tahun as tahun, " +
            "d.approveStatus as approveStatus, " +
            "d.vpApproveDate as vpApproveDate, " +
            "d.komiteApproveDate as komiteApproveDate, " +
            "d.direkturApproveDate as direkturApproveDate " +
            "FROM Drp d " +
            "WHERE d.isDelete = false")
    Page<DrpApprovalView> getListApprovalDrp(Pageable pageable);



    @Query(value = "SELECT d.id as id, " +
            "d.tahun as tahun, " +
            "d.isPrint as isPrint, " +
            "d.printDate as printDate " +
            "FROM Drp d " +
            "WHERE d.isDelete = false")
    Page<DrpView> getListPrintDrp(Pageable pageable);

}
