package com.iconplus.smartproc.service.approval;

import com.iconplus.smartproc.helper.model.Pagination;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.projection.DrpRekomendasiView;
import com.iconplus.smartproc.model.request.DrpRekomendasiRequest;
import com.iconplus.smartproc.model.response.DrpRekomendasiResponse;
import com.iconplus.smartproc.model.response.GetListDrpRekomendasiResponse;
import com.iconplus.smartproc.repository.DrpRekomendasiRepository;
import org.apache.commons.lang3.BooleanUtils;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

@Service
public class GetListRekomendasiService implements BaseService<DrpRekomendasiRequest, GetListDrpRekomendasiResponse> {

    private final DrpRekomendasiRepository drpRekomendasiRepository;

    public GetListRekomendasiService(DrpRekomendasiRepository drpRekomendasiRepository) {
        this.drpRekomendasiRepository = drpRekomendasiRepository;
    }

    @Override
    public GetListDrpRekomendasiResponse execute(DrpRekomendasiRequest input) {

        List<DrpRekomendasiResponse> drpRekomendasiResponseList = new ArrayList<>();
        var listDrpRekomendasi = drpRekomendasiRepository.getListDrpRekomendasi(input.getJenisPengadaanId(), input.getPageable());
        for (DrpRekomendasiView drpRekomendasiView : listDrpRekomendasi) {
            DrpRekomendasiResponse drpRekomendasiResponse = DrpRekomendasiResponse.builder()
                    .id(drpRekomendasiView.getId())
                    .jabatan(drpRekomendasiView.getJabatan())
                    .rekomendasi(drpRekomendasiView.getRekomendasi())
                    .rekomendasiDate(drpRekomendasiView.getRekomendasiDate())
                    .build();
            if (drpRekomendasiView.getIsApprove() != null) {
                if (BooleanUtils.isTrue(drpRekomendasiView.getIsApprove())) {
                    drpRekomendasiResponse.setStatus("Setuju");
                } else {
                    drpRekomendasiResponse.setStatus("Tolak");
                }
            }

            drpRekomendasiResponseList.add(drpRekomendasiResponse);
        }

        return GetListDrpRekomendasiResponse.builder()
                .data(drpRekomendasiResponseList)
                .pagination(Pagination.builder()
                        .pageSize(input.getPageable().getPageSize())
                        .currentPage(input.getPageable().getPageNumber())
                        .totalPages(listDrpRekomendasi.getTotalPages())
                        .totalRecords(listDrpRekomendasi.getTotalElements())
                        .isFirstPage(listDrpRekomendasi.isFirst())
                        .isLastPage(listDrpRekomendasi.isLast())
                        .build())
                .build();
    }
}
