package com.iconplus.smartproc.service.drp;

import com.iconplus.smartproc.exception.BusinessException;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.request.DrpDokumenRequest;
import com.iconplus.smartproc.model.response.DrpDokumenResponse;
import com.iconplus.smartproc.repository.DrpDokumenRepository;
import com.iconplus.smartproc.util.Constants;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

@Service
public class PostDrpUploadDokumenRKAPService implements BaseService<DrpDokumenRequest, DrpDokumenResponse> {

    @Value("${config.file-upload.rkap}")
    private String pathFileUploadRkap;

    private final DrpDokumenRepository drpDokumenRepository;
    public PostDrpUploadDokumenRKAPService(DrpDokumenRepository drpDokumenRepository) {
        this.drpDokumenRepository = drpDokumenRepository;
    }

    @Override
    public DrpDokumenResponse execute(DrpDokumenRequest input) throws IOException {

        MultipartFile file = input.getFile();
        String fileName = file.getOriginalFilename();

        var drpDokumen= drpDokumenRepository.findByFilenameAndIsDeleteFalse(fileName);
        if (drpDokumen.isPresent()) {
            throw new BusinessException(Constants.ERR_CODE_10002,
                    Constants.ERR_TTL_10002,
                    String.format(Constants.ERR_MSG_10002, "Filename", fileName));
        }

        File path = new File(pathFileUploadRkap + fileName);

        try {
            FileOutputStream output = new FileOutputStream(path);
            output.write(file.getBytes());
            output.close();
        } catch (Exception ex) {
            throw new BusinessException(Constants.ERR_CODE_10012,
                    Constants.ERR_TTL_10012,
                    String.format(Constants.ERR_MSG_10012, pathFileUploadRkap));
        }

        return DrpDokumenResponse.builder()
                .jenisDokumenId(input.getJenisDokumenId())
                .filename(fileName)
                .keterangan(input.getKeterangan())
                .build();
    }
}
