package com.iconplus.smartproc.service.drppengadaan;

import com.iconplus.smartproc.exception.BusinessException;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.entity.DrpPengadaanDokumen;
import com.iconplus.smartproc.model.request.DrpPengadaanRequest;
import com.iconplus.smartproc.model.response.DrpPengadaanDokumenResponse;
import com.iconplus.smartproc.model.response.DrpPengadaanResponse;
import com.iconplus.smartproc.repository.DrpPengadaanDokumenRepository;
import com.iconplus.smartproc.repository.DrpPengadaanRepository;
import com.iconplus.smartproc.util.Constants;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

@Service
@Slf4j
public class GetDrpPengadaanService implements BaseService<DrpPengadaanRequest, DrpPengadaanResponse> {

    private final DrpPengadaanRepository drpPengadaanRepository;
    private final DrpPengadaanDokumenRepository drpPengadaanDokumenRepository;

    public GetDrpPengadaanService(DrpPengadaanRepository drpPengadaanRepository,
                                  DrpPengadaanDokumenRepository drpPengadaanDokumenRepository) {
        this.drpPengadaanRepository = drpPengadaanRepository;
        this.drpPengadaanDokumenRepository = drpPengadaanDokumenRepository;
    }

    @Override
    public DrpPengadaanResponse execute(DrpPengadaanRequest input) {

        var drpPengadaan = drpPengadaanRepository.getDrpPengadaanById(input.getId())
                .orElseThrow(() -> new BusinessException(Constants.ERR_CODE_10001,
                        Constants.ERR_TTL_10001,
                        String.format(Constants.ERR_MSG_10001, "DRP Pengadaan", input.getId())));

        List<DrpPengadaanDokumenResponse> drpPengadaanDokumenResponseList = new ArrayList<>();
        var drpPengadaanDokumenList = drpPengadaanDokumenRepository.findByDrpPengadaanIdAndIsDeleteFalse(drpPengadaan.getId());
        for (DrpPengadaanDokumen drpPengadaanDokumen : drpPengadaanDokumenList) {
            DrpPengadaanDokumenResponse drpPengadaanDokumenResponse = DrpPengadaanDokumenResponse.builder()
                    .id(drpPengadaanDokumen.getId())
                    .drpId(drpPengadaanDokumen.getDrpId())
                    .jenisDokumenId(drpPengadaanDokumen.getJenisDokumenId())
                    .filename(drpPengadaanDokumen.getFilename())
                    .keterangan(drpPengadaanDokumen.getKeterangan())
                    .build();
            drpPengadaanDokumenResponseList.add(drpPengadaanDokumenResponse);
        }


        return DrpPengadaanResponse.builder()
                .id(drpPengadaan.getId())
                .drpId(drpPengadaan.getDrpId())
                .nomor(drpPengadaan.getNomor())
                .namaPengadaan(drpPengadaan.getNamaPengadaan())
                .lokasiId(drpPengadaan.getLokasiId())
                .lokasi(drpPengadaan.getLokasi())
                .jenisPengadaanId(drpPengadaan.getJenisPengadaanId())
                .jenisPengadaan(drpPengadaan.getJenisPengadaan())
                .unitInisiatorId(drpPengadaan.getUnitInisiatorId())
                .unitInisiator(drpPengadaan.getUnitInisiator())
                .hpe(drpPengadaan.getHpe())
                .pagu(drpPengadaan.getPagu())
                .sumberDanaId(drpPengadaan.getSumberDanaId())
                .sumberDana(drpPengadaan.getSumberDana())
                .metodePengadaanId(drpPengadaan.getMetodePengadaanId())
                .metodePengadaan(drpPengadaan.getMetodePengadaan())
                .supplyPositioningMatrixId(drpPengadaan.getSupplyPositioningMatrixId())
                .supplyPositioningMatrix(drpPengadaan.getSupplyPositioningMatrix())
                .metodePenyampaianId(drpPengadaan.getMetodePenyampaianId())
                .metodePenyampaian(drpPengadaan.getMetodePenyampaian())
                .jenisKontrakId(drpPengadaan.getJenisKontrakId())
                .jenisKontrak(drpPengadaan.getJenisKontrak())
                .strategiPengadaanId(drpPengadaan.getStrategiPengadaanId())
                .strategiPengadaan(drpPengadaan.getStrategiPengadaan())
                .rencanaTanggal(drpPengadaan.getRencanaTanggal())
                .targetTanggal(drpPengadaan.getTargetTanggal())
                .isActive(drpPengadaan.getIsActive())
                .dataDrpPengadaanDokumen(drpPengadaanDokumenResponseList)
                .build();
    }
}
