package com.iconplus.smartproc.service.rksdaftarisi;

import com.iconplus.smartproc.exception.BusinessException;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.entity.RksIsi;
import com.iconplus.smartproc.model.request.RksIsiRequest;
import com.iconplus.smartproc.model.response.RksIsiResponse;
import com.iconplus.smartproc.repository.RksIsiRepository;
import com.iconplus.smartproc.util.Constants;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

@Service
public class PostCreateRksIsiService implements BaseService<RksIsiRequest, RksIsiResponse> {

    private final RksIsiRepository rksIsiRepository;
    public PostCreateRksIsiService(RksIsiRepository rksIsiRepository) {
        this.rksIsiRepository = rksIsiRepository;
    }

    @Override
    public RksIsiResponse execute(RksIsiRequest input) {

        RksIsi rksIsi = RksIsi.builder().build();
        validasiRequest(input, rksIsi);

        rksIsi.setRksDaftarIsiId(input.getRksDaftarIsiId());
        rksIsi.setNomor(input.getNomor());
        rksIsi.setUrutan(input.getUrutan());
        rksIsi.setIsKontrak(input.getIsKontrak());
        rksIsi.setIsDelete(false);
        var result = rksIsiRepository.save(rksIsi);

        return RksIsiResponse.builder()
                .id(result.getId())
                .build();
    }

    private void validasiRequest(RksIsiRequest input, RksIsi rksIsi) {
        if (StringUtils.isNotBlank(input.getNama())) {
            var optionalRksIsi = rksIsiRepository.findByRksDaftarIsiIdAndNamaAndIsDeleteFalse(input.getRksDaftarIsiId(), input.getNama());
            if (optionalRksIsi.isPresent()) {
                throw new BusinessException(
                        Constants.ERR_CODE_10002,
                        Constants.ERR_TTL_10002,
                        String.format(Constants.ERR_MSG_10002, "Nama Buku", input.getNama()));
            }
            rksIsi.setNama(input.getNama());
            return;
        }

        if (StringUtils.isNotBlank(input.getBab())) {
            var optionalRksIsi = rksIsiRepository.findByRksDaftarIsiIdAndBabAndIsDeleteFalse(input.getRksDaftarIsiId(), input.getBab());
            if (optionalRksIsi.isPresent()) {
                throw new BusinessException(
                        Constants.ERR_CODE_10002,
                        Constants.ERR_TTL_10002,
                        String.format(Constants.ERR_MSG_10002, "Bab", input.getBab()));
            }
            rksIsi.setParent(input.getParent());
            rksIsi.setBab(input.getBab());
            return;
        }

        if (StringUtils.isNotBlank(input.getSubBab())) {

            var optionalRksIsi = rksIsiRepository.findByRksDaftarIsiIdAndSubBabAndIsDeleteFalse(input.getRksDaftarIsiId(), input.getSubBab());
            if (optionalRksIsi.isPresent()) {
                throw new BusinessException(
                        Constants.ERR_CODE_10002,
                        Constants.ERR_TTL_10002,
                        String.format(Constants.ERR_MSG_10002, "Sub Bab", input.getSubBab()));
            }
            rksIsi.setParent(input.getParent());
            rksIsi.setSubBab(input.getSubBab());
            return;
        }

        if (StringUtils.isNotBlank(input.getKelompok())) {

            var optionalRksIsi = rksIsiRepository.findByRksDaftarIsiIdAndKelompokAndIsDeleteFalse(input.getRksDaftarIsiId(), input.getKelompok());
            if (optionalRksIsi.isPresent()) {
                throw new BusinessException(
                        Constants.ERR_CODE_10002,
                        Constants.ERR_TTL_10002,
                        String.format(Constants.ERR_MSG_10002, "Sub Bab", input.getSubBab()));
            }
            rksIsi.setParent(input.getParent());
            rksIsi.setKelompok(input.getSubBab());
        }
    }
}
