package com.iconplus.smartproc.service.rksdaftarisi;

import com.iconplus.smartproc.exception.BusinessException;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.request.RksIsiRequest;
import com.iconplus.smartproc.model.response.RksIsiResponse;
import com.iconplus.smartproc.repository.RksIsiRepository;
import com.iconplus.smartproc.util.Constants;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

@Service
public class PutEditRksIsiService implements BaseService<RksIsiRequest, RksIsiResponse> {

    private final RksIsiRepository rksIsiRepository;
    public PutEditRksIsiService(RksIsiRepository rksIsiRepository) {
        this.rksIsiRepository = rksIsiRepository;
    }

    @Override
    public RksIsiResponse execute(RksIsiRequest input) {

        var rksIsi = rksIsiRepository.findByIdAndIsDeleteFalse(input.getId())
                .orElseThrow(() -> new BusinessException(
                        Constants.ERR_CODE_10001,
                        Constants.ERR_TTL_10001,
                        String.format(Constants.ERR_MSG_10001, "RKS Isi", input.getId())
                ));

        if (StringUtils.isNotBlank(input.getNama())) {
            rksIsi.setNama(input.getNama());
        } else if (StringUtils.isNotBlank(input.getBab())) {
            rksIsi.setBab(input.getBab());
        } else if (StringUtils.isNotBlank(input.getSubBab())) {
            rksIsi.setSubBab(input.getSubBab());
        } else {
            rksIsi.setKelompok(input.getKelompok());
        }

        rksIsi.setUrutan(input.getUrutan());
        rksIsi.setIsKontrak(input.getIsKontrak());
        rksIsiRepository.save(rksIsi);

        return RksIsiResponse.builder()
                .id(rksIsi.getId())
                .build();
    }
}
