package com.iconplus.smartproc.service.rkstemplate;

import com.iconplus.smartproc.exception.BusinessException;
import com.iconplus.smartproc.helper.model.EmptyResponse;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.request.RksTemplateRequest;
import com.iconplus.smartproc.repository.RksTemplateRepository;
import com.iconplus.smartproc.util.Constants;
import org.springframework.stereotype.Service;

@Service
public class DeleteRksTemplateService implements BaseService<RksTemplateRequest, EmptyResponse> {

    private final RksTemplateRepository rksTemplateRepository;

    public DeleteRksTemplateService(RksTemplateRepository rksTemplateRepository) {
        this.rksTemplateRepository = rksTemplateRepository;
    }

    @Override
    public EmptyResponse execute(RksTemplateRequest input) {
        var rksTemplate = rksTemplateRepository.findByIdAndIsDeleteFalse(input.getId())
                .orElseThrow(()-> new BusinessException(
                        Constants.ERR_CODE_10001,
                        Constants.ERR_TTL_10001,
                        String.format(Constants.ERR_MSG_10001, "RKS Template", input.getId())
                ));

        rksTemplate.setIsDelete(true);
        rksTemplateRepository.save(rksTemplate);

        return new EmptyResponse();
    }
}
